==> haskell-xcffib-1.6.0-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xcffib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xcffib
version:              1.6.0
visibility:           public
id:                   xcffib-1.6.0-4FKQMGGKsM220qm05vz5eg
key:                  xcffib-1.6.0-4FKQMGGKsM220qm05vz5eg
license:              Apache-2.0
maintainer:           Tycho Andersen <tycho@tycho.pizza>
author:               Tycho Andersen
homepage:             http://github.com/tych0/xcffib
synopsis:             A cffi-based python binding for X
description:          A cffi-based python binding for X, comparable to xpyb
category:             X11
abi:                  f1be23c86e59d4e9e62f2f30bc52d7f1
exposed:              True
exposed-modules:
    Data.XCB.Python.AST Data.XCB.Python.Parse Data.XCB.Python.PyHelpers

import-dirs:          /usr/lib/ghc-9.4.8/site-local/xcffib-1.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xcffib-1.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xcffib-1.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xcffib
hs-libraries:         HSxcffib-1.6.0-4FKQMGGKsM220qm05vz5eg
depends:
    attoparsec-0.14.4-HrmGc7uWcHZBxPSUhHwhWb base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    either-5.0.3-BtcezSfqlh64PFukFhtSzB
    filemanip-0.3.6.3-LHOt6HIL9F5U3Fm9jc30U filepath-1.4.2.2 mtl-2.2.2
    pretty-1.1.3.6 split-0.2.5-Dujwwofvw7aEFmjRmWhj9Q
    xcb-types-0.15.0-HIw3n37qHy923j0eWzIL5J

haddock-interfaces:   /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html:         /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xcffib-1.6.0-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xcffib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xcffib
version:              1.6.0
visibility:           public
id:                   xcffib-1.6.0-AZF9kqwOTN1EzlJTscgG8w
key:                  xcffib-1.6.0-AZF9kqwOTN1EzlJTscgG8w
license:              Apache-2.0
maintainer:           Tycho Andersen <tycho@tycho.pizza>
author:               Tycho Andersen
homepage:             http://github.com/tych0/xcffib
synopsis:             A cffi-based python binding for X
description:          A cffi-based python binding for X, comparable to xpyb
category:             X11
abi:                  20d956076cc20477d03280844fb3c614
exposed:              True
exposed-modules:
    Data.XCB.Python.AST Data.XCB.Python.Parse Data.XCB.Python.PyHelpers

import-dirs:          /usr/lib/ghc-9.4.8/site-local/xcffib-1.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xcffib-1.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xcffib-1.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xcffib
hs-libraries:         HSxcffib-1.6.0-AZF9kqwOTN1EzlJTscgG8w
depends:
    attoparsec-0.14.4-C65PLyhXhiCHiJkC3KuQ9j base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    either-5.0.3-CST4FwrsSwpKgQT70DzwaP
    filemanip-0.3.6.3-BuqrcmTVkIsJ8xnrguINaL filepath-1.4.2.2 mtl-2.2.2
    pretty-1.1.3.6 split-0.2.5-LouByQg2aGcJvOHmCntrU0
    xcb-types-0.15.0-HIw3n37qHy923j0eWzIL5J

haddock-interfaces:   /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html:         /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
